@@ -1,18 +1,20 @@
 import re
+
 try:
     from . import i18n
     from . import connect_core
+    from . import log
     from . import screens
     from . import command
 except ModuleNotFoundError:
     import i18n
     import connect_core
+    import log
     import screens
     import command
 
 
 def get_time(api) -> str:
-
     cmd_list = list()
     cmd_list.append(command.GoMainMenu)
     cmd_list.append('A')
@@ -28,6 +30,7 @@ def get_time(api) -> str:
                 i18n.Success,
             ],
             screens.Target.MainMenu,
+            log_level=log.level.DEBUG,
             break_detect=True),
     ]
 
